<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>DotPlotDialog</name>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="20"/>
        <source>Compare sequences using Dotplot</source>
        <translation>Сравнение последовательностей при помощи Dotplot</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="33"/>
        <source>Dotplot parameters</source>
        <translation>Dotplot параметры</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="55"/>
        <source>Custom algorithm</source>
        <translation>Алгоритм по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="102"/>
        <source>X axis sequence</source>
        <translation>Последовательность оси X</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="115"/>
        <source>Minimum repeat length</source>
        <translation>Мин длина повторов</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="122"/>
        <source>Y axis sequence</source>
        <translation>Последовательность оси Y</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="129"/>
        <source>Repeats  identity</source>
        <translation>Идентичность повторов</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="158"/>
        <source>bp</source>
        <translation>нк</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="186"/>
        <source>Heuristic based selection of repeat length so the number of repeats in the sequence will not exceed 1000</source>
        <translation>Эвристический подбор длины повторов, с тем чтобы кол-во повторов в последовательности не превысило 1000</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="189"/>
        <source>1k</source>
        <translation>1к</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="218"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="240"/>
        <source>Resets repeats identity to 100%</source>
        <translation>Сбросить к 100%</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="243"/>
        <source>100</source>
        <translation>100</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="298"/>
        <source>Search inverted repeats</source>
        <translation>Искать инвертированные повторы</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="305"/>
        <source>Search direct repeats</source>
        <translation>Искать прямые повторы</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="344"/>
        <location filename="../src/DotPlotDialog.ui" line="351"/>
        <source>default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="376"/>
        <source>Click to load a sequence from the file system. The sequence will be added to the combo boxes when it is loaded to the project</source>
        <translation>Нажмите, чтобы загрузить последовательности из файловой системы. Последовательности будут добавлены в комбо-боксы, когда они будут загружены в проект</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.ui" line="379"/>
        <source>Load Sequence</source>
        <translation>Загрузить</translation>
    </message>
</context>
<context>
    <name>DotPlotFilesDialog</name>
    <message>
        <location filename="../src/DotPlotFilesDialog.ui" line="38"/>
        <location filename="../src/DotPlotFilesDialog.ui" line="72"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.ui" line="23"/>
        <source>Build Dotplot from Sequences</source>
        <translation>Построить dotplot последовательностей</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.ui" line="55"/>
        <source>File with first sequence</source>
        <translation>Файл с первой последовательностью</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.ui" line="45"/>
        <location filename="../src/DotPlotFilesDialog.ui" line="96"/>
        <source>Join all sequences found in the file</source>
        <translation>Соединить последовательности</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.ui" line="62"/>
        <location filename="../src/DotPlotFilesDialog.ui" line="130"/>
        <source>Gap size:</source>
        <translation>Длина пробела:</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.ui" line="79"/>
        <source>Compare sequence against itself</source>
        <translation>Саму с собой</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.ui" line="103"/>
        <source>File with second sequence</source>
        <translation>Файл со второй последовательностью</translation>
    </message>
</context>
<context>
    <name>DotPlotFilterDialog</name>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="17"/>
        <source>DotPlot</source>
        <translation>DotPlot</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="30"/>
        <source>Dotplot parameters</source>
        <translation>Параметры фильтрации</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="42"/>
        <source>No filtration applied</source>
        <translation>Фильтрация не применяется</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="45"/>
        <source>No Filtration</source>
        <translation>Без фильтрации</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="55"/>
        <source>Show results that intersect the features</source>
        <translation>показывать результаты, которые пересекают аннотации</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="58"/>
        <source>Features Intersection</source>
        <translation>Пересечение аннотаций</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="65"/>
        <source>Intersection Parameters</source>
        <translation>Параметры пересечения</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="72"/>
        <source>Feature Name</source>
        <translation>Имя аннотации</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="80"/>
        <source>Select all names</source>
        <translation>Выбрать все имена</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="83"/>
        <source>Select All</source>
        <translation>Выбрать все</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="90"/>
        <source>Invert the current selection</source>
        <translation>Инвертировать текущее выделение</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="93"/>
        <source>Invert Selection</source>
        <translation>Инвертировать</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="100"/>
        <source>Clear the current selection</source>
        <translation>Очистить текущее выделение</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="103"/>
        <source>Clear Selection</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="110"/>
        <source>Select names of the features to intersection</source>
        <translation>Выберете имена аннотаций для пересечения</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="113"/>
        <source>Features Selection</source>
        <translation>Выбор аннотаций</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="139"/>
        <source>Select only different names</source>
        <translation>Выбрать только различные имена</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.ui" line="142"/>
        <source>Different Only</source>
        <translation>Различные</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotDialog</name>
    <message>
        <location filename="../src/DotPlotDialog.cpp" line="54"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.cpp" line="55"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.cpp" line="65"/>
        <source>Auto</source>
        <translation>Автовыбор</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.cpp" line="66"/>
        <source>Suffix index</source>
        <translation>Суффиксный индекс</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.cpp" line="67"/>
        <source>Diagonals</source>
        <translation>Диагональный</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.cpp" line="312"/>
        <source>Open file</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.cpp" line="341"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.cpp" line="341"/>
        <source>Error opening files</source>
        <translation>Ошибка открытия файлов</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotFilesDialog</name>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="41"/>
        <source>Next</source>
        <translation>Далее</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="73"/>
        <source>Open first file</source>
        <translation>Открыть первый файл</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="104"/>
        <source>Open second file</source>
        <translation>Открыть второй файл</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="140"/>
        <source>Select a file with a sequence to build dotplot!</source>
        <translation>Выберите файл с последовательностью!</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="140"/>
        <source>Select first file with a sequence to build dotplot!</source>
        <translation>Выберите первый файл с последовательностью!</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="141"/>
        <source>Input the second sequence or check the &apos;Compare sequence against itself&apos; option.</source>
        <translation>Выберите вторую последовательность или выберите опцию &apos;Сравнить последовательность саму с собой&apos;.</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="150"/>
        <location filename="../src/DotPlotFilesDialog.cpp" line="158"/>
        <source>Unable to detect file format %1.</source>
        <translation>Невозможно определить формат файла %1.</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="142"/>
        <location filename="../src/DotPlotFilesDialog.cpp" line="150"/>
        <location filename="../src/DotPlotFilesDialog.cpp" line="158"/>
        <source>Select files</source>
        <translation>Выберите файлы</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotFilterDialog</name>
    <message>
        <location filename="../src/DotPlotFilterDialog.cpp" line="45"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.cpp" line="139"/>
        <source>Feature names</source>
        <translation>Имена аннотаций</translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilterDialog.cpp" line="139"/>
        <source>No feature names have been selected. In that case dotplot will be empty. Note, If the feature names list is empty your sequences don&apos;t have annotations. Select some feature names or choose another filtration method</source>
        <translation>Имена аннотаций не были выбраны. В этом случае dotplot будет пустым. Если список аннотаций пустой, то ваши последовательности не содержат аннотации. Выберете несколько имен аннотаций или другой метод фильтрации</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotFilterTask</name>
    <message>
        <location filename="../src/DotPlotTasks.cpp" line="308"/>
        <source>Applying filter to dotplot</source>
        <translation>Применение фильтра к dotplot</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotImageExportController</name>
    <message>
        <location filename="../src/DotPlotImageExportTask.cpp" line="60"/>
        <source>Dotplot widget is NULL</source>
        <translation>Dotplot widget is NULL</translation>
    </message>
    <message>
        <location filename="../src/DotPlotImageExportTask.cpp" line="61"/>
        <source>Dotplot</source>
        <translation>Dotplot</translation>
    </message>
    <message>
        <location filename="../src/DotPlotImageExportTask.cpp" line="78"/>
        <source>Include area selection</source>
        <translation>Включить область выделения</translation>
    </message>
    <message>
        <location filename="../src/DotPlotImageExportTask.cpp" line="79"/>
        <source>Include repeat selection</source>
        <translation>Включить повторяющиеся выделения</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotImageExportToBitmapTask</name>
    <message>
        <location filename="../src/DotPlotImageExportTask.cpp" line="49"/>
        <source>Incorrect DPI parameter</source>
        <translation>Incorrect DPI parameter</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotLoadDocumentsTask</name>
    <message>
        <location filename="../src/DotPlotTasks.cpp" line="215"/>
        <source>DotPlot loading</source>
        <translation>Dotplot загружается</translation>
    </message>
    <message>
        <location filename="../src/DotPlotTasks.cpp" line="257"/>
        <source>Detecting format error for file %1</source>
        <translation>Ошибка определения формата файла %1</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotPlugin</name>
    <message>
        <location filename="../src/DotPlotPlugin.cpp" line="54"/>
        <source>Dotplot</source>
        <translation>Dotplot</translation>
    </message>
    <message>
        <location filename="../src/DotPlotPlugin.cpp" line="54"/>
        <source>Build dotplot for sequences</source>
        <translation>Построение dotplot для последовательностей</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotSplitter</name>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="46"/>
        <source>Multiple view synchronization lock</source>
        <translation>Синхронизация нескольких окон</translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="47"/>
        <source>Filter results</source>
        <translation>Фильтрация результатов</translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="48"/>
        <source>Zoom in (&lt;b&gt; + &lt;/b&gt;)</source>
        <translation>Приблизить (&lt;b&gt; + &lt;/b&gt;)</translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="49"/>
        <source>Zoom out (&lt;b&gt; - &lt;/b&gt;)</source>
        <translation>Удалить (&lt;b&gt; - &lt;/b&gt;)</translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="50"/>
        <source>Reset zooming (&lt;b&gt;0&lt;/b&gt;)</source>
        <translation>Масштабировать к исходному размеру (&lt;b&gt; 0 &lt;/b&gt;)</translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="51"/>
        <source>Select tool (&lt;b&gt;S&lt;/b&gt;)</source>
        <translation>Выделение (&lt;b&gt;S&lt;/b&gt;)</translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="52"/>
        <source>Hand tool (&lt;b&gt;H&lt;/b&gt;)</source>
        <translation>Рука (&lt;b&gt;H&lt;/b&gt;)</translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="279"/>
        <source>One of the sequences in dotplot is NULL</source>
        <translation>One of the sequences in dotplot is NULL</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotViewAction</name>
    <message>
        <location filename="../src/DotPlotPlugin.h" line="81"/>
        <source>Show dot plot</source>
        <translation>Показать dotplot</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotViewContext</name>
    <message>
        <location filename="../src/DotPlotPlugin.cpp" line="72"/>
        <location filename="../src/DotPlotPlugin.cpp" line="221"/>
        <source>Build dotplot...</source>
        <translation>Построение точечной диаграммы (dotplot)...</translation>
    </message>
    <message>
        <location filename="../src/DotPlotPlugin.cpp" line="91"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/DotPlotPlugin.cpp" line="91"/>
        <source>Error opening files</source>
        <translation>Ошибка открытия файлов</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotWidget</name>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="120"/>
        <source>Parameters</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="123"/>
        <source>Save as image</source>
        <translation>Сохранить как изображение</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="127"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="131"/>
        <source>Load</source>
        <translation>Загрузить</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="134"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="138"/>
        <source>Filter Results</source>
        <translation>Фильтрация результатов</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="208"/>
        <source>Save/Load</source>
        <translation>Сохранить/Загрузить</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="385"/>
        <source>Too many results</source>
        <translation>Слишком много результатов</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="385"/>
        <source>Too many results. Try to increase minimum repeat length</source>
        <translation>Слишком много результатов. Попробуйте уменьшить минимальную длину повтора</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="536"/>
        <location filename="../src/DotPlotWidget.cpp" line="592"/>
        <source>File opening error</source>
        <translation>Ошибка открытия файла</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="536"/>
        <location filename="../src/DotPlotWidget.cpp" line="592"/>
        <source>Error opening file %1</source>
        <translation>Ошибка открытия файла %1</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="544"/>
        <location filename="../src/DotPlotWidget.cpp" line="574"/>
        <location filename="../src/DotPlotWidget.cpp" line="642"/>
        <source>Task is already running</source>
        <translation>Задача уже запущена</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="544"/>
        <location filename="../src/DotPlotWidget.cpp" line="574"/>
        <location filename="../src/DotPlotWidget.cpp" line="642"/>
        <source>Build or Load DotPlot task is already running</source>
        <translation>Задача построения или загрузки dotplot уже запущена</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="596"/>
        <source>Sequences are different</source>
        <translation>Последовательности отличаются</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="596"/>
        <source>Current and loading sequences are different. Continue loading dot-plot anyway?</source>
        <translation>Текущая и загружаемая последовательность различаются. Продолжить загрузку?</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="697"/>
        <location filename="../src/DotPlotWidget.cpp" line="702"/>
        <source>Invalid sequence</source>
        <translation>Некорректная последовательность</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="697"/>
        <source>First selected sequence is invalid</source>
        <translation>Первая выделенная последовательность некорректна</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="702"/>
        <source>Second selected sequence is invalid</source>
        <translation>Вторая выделенная последовательность некорректна</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="710"/>
        <source>Wrong alphabet types</source>
        <translation>Неправильные типы алфавитов</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="710"/>
        <source>Both sequence must have the same alphabet</source>
        <translation>Обе последовательности должны иметь одинаковый алфавит</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="789"/>
        <location filename="../src/DotPlotWidget.cpp" line="791"/>
        <source>Save dot-plot</source>
        <translation>Сохранить dotplot</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="789"/>
        <location filename="../src/DotPlotWidget.cpp" line="791"/>
        <source>Save dot-plot data before closing?</source>
        <translation>Сохранить данные dotplot перед закрытием?</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="931"/>
        <source>Invalid weight and height parameters!</source>
        <translation>Некорректные параметры!</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="980"/>
        <source>Dotplot widget is too small</source>
        <translation>Виджет точечной диаграммы слишком маленький</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="991"/>
        <source>Dotplot is calculating...</source>
        <translation>Выполняется расчёт...</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="1035"/>
        <source> (min length %1, identity %2%)</source>
        <translation> (мин. длина %1, идентичность %2%)</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="206"/>
        <source>Dotplot</source>
        <translation>Dotplot</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="521"/>
        <source>Error Saving Dotplot</source>
        <translation>Ошибка сохранения</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="521"/>
        <source>The dotplot can&apos;t be saved as it is empty.</source>
        <translation>Дотплот не может быть сохранён, т.к. он пуст.</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="525"/>
        <source>Save Dotplot</source>
        <translation>Сохранить dotplot</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="525"/>
        <location filename="../src/DotPlotWidget.cpp" line="567"/>
        <source>Dotplot files (*.dpt)</source>
        <translation>Файлы dotplot (*.dpt)</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="567"/>
        <source>Load Dotplot</source>
        <translation>Загрузить dotplot</translation>
    </message>
</context>
<context>
    <name>U2::LoadDotPlotTask</name>
    <message>
        <location filename="../src/DotPlotTasks.cpp" line="59"/>
        <source>Wrong dotplot format</source>
        <translation>Неправильный формат файла dotplot</translation>
    </message>
    <message>
        <location filename="../src/DotPlotTasks.h" line="88"/>
        <source>DotPlot loading</source>
        <translation>Dotplot загружается</translation>
    </message>
</context>
<context>
    <name>U2::SaveDotPlotTask</name>
    <message>
        <location filename="../src/DotPlotTasks.h" line="49"/>
        <source>DotPlot saving</source>
        <translation>Dotplot сохраняется</translation>
    </message>
</context>
</TS>
